---
title: "Religion and Rational Belief"
date: 2021-07-22T15:50:59Z
tags: ["belief","assent","newman",""]
topics: ["philosophy","theology"]
image: img/flammarion.jpg
draft: false
---

This paper is an analysis of the following argument that denies the possibility of rationality in religious faith:

1) Rational belief is belief that is proportioned to the evidence.
2) Religious faith is belief that is unsupported by the evidence.
3) C) Therefore, religious faith is never rational.

To assess this argument properly, a number of key assumptions need to be examined and critiqued. First, premise 1 implies without explanation a nature of belief that allows for proportionality. Second, premise 1 also asserts a proportionality standard of rationality which is contestable on a proper understanding of belief as assent. This means that the first two premises anchor proportionality in a notion of evidence. Third, premise 2 asserts a definition of faith that erroneously eliminates the possibility of rationality by making it wholly dependent upon its prior assumptions about proportionality and evidence. Finally, it draws a conclusion which cannot be sustained even if we were to accept the first two premises.

The argument of this paper will proceed by addressing each of these enumerated assumptions in turn. First, it will briefly outline a plausible notion of religious belief as assent, inspired by John Henry Newman. Next, it will reject proportionality as a standard for rational belief, on the ground that assent cannot be proportional. It will then explore two notions of rationality provided by Alvin Plantinga to show that idea of rationality employed by the syllogism under scrutiny is inadequate to its conclusion. The essay will then address the question of evidence, from both the perspective of metaphysics and the philosophy of science, to show that the syllogism is relying on the concept for too much. Next, it will offer a condensed formulation of the idea of faith from contemporary research, taking the clarified concept of rationality into account. Finally, this paper will conclude that, given this more complete understanding of belief, rationality, evidence, and faith, the argument under scrutiny is unconvincing.

**I. Apprehension Precedes Belief**

Apprehension, according to philosopher and theologian John Henry Newman, is ‘the imposition of a sense on the terms of which [propositions] are composed'[^1] and more broadly, ‘simply an intelligent acceptance of the idea or fact which a proposition enunciates’, and he differentiates assent from inference to make the point, saying, ‘we cannot assent to a proposition without some intelligent apprehension of it; whereas we need not understand it at all in order to infer it’.[^2]  To borrow the examples from his *Grammar of Assent*, we cannot give assent to the proposition that ‘x is z’ until we are told something about the terms. However, it is easy enough to understand the meanings of the words in a proposition like ‘pride comes before a fall’ or ‘Napoleon died at St. Helena’. Though, it need not be the case that I know where St. Helena is, or what sort of falls proceed from pride or why pride would precipitate a fall, in order to apprehend the propositions.

According to Newman, apprehension comes in two forms: real and notional. As he puts it,

> the terms of a proposition do or do not stand for things. If they do, then they are singular terms, for all things that are, are units. But if they do not stand for things they must stand for notions, and are common terms. Singular nouns come from experience, common from abstraction. The apprehension of the former I call real, and the latter, notional.[^3] 

Referring back to the examples above, then, Napoleon dying at St. Helena would be an example of real apprehension, because we have ‘an experience *or information* about a concrete’.[^4]  The individual man Napoleon, and the individual place St. Helena. But pride coming before a fall would be an example of *notional* apprehension, because what is in mind, is an abstraction drawn from the recognition of patterned likenesses, and as David Hume might put it, a constant conjunction of prideful attitudes, followed by falls.

In employing the idea of ‘notional apprehension’, Newman is borrowing the concept of categories from Aristotle. Newman describes the process this way:

> …we apprehend… that man is like man, yet unlike; and unlike a horse, a tree, a mountain, or a monument; yet in some, though not in the same respects, like each of them. And in consequence…we are ever grouping and discriminating… and thereby rising from particulars to generals, that is from images to notions.[^5] 

It is possible, according to Newman, to arrive at a notional apprehension without a direct experience. In fact, Newman says the habit in society is to ‘regard things not as they are in themselves, but mainly as they stand in relation to one another’,[^6]  and in so doing, abstract away the real being of particular things into their definitional classifications. As he put it,

> …individual propositions about the concrete almost cease to be, and are diluted or starved into abstract notions… all that fullness of meaning which I have described as accruing to language from experience, now that experience is absent, necessarily becomes to the multitude of men nothing but a heap of notions, little more intelligible than the beauties of a prospect to the short-sighted man, or the musice of a great master, to the listener who has no ear.[^7] 

Newman argues that the real and the notional are complementary forms of apprehension, but that real apprehension is primary. He says, ‘without the apprehension of notions, we would forever pace around in one small circle of knowledge… however real apprehension has precedence, as being the scope and end and the test of the notional’, and, ‘to apprehend notionally is to have breadth of mind, but to be shallow; to apprehend really, is to be deep but to be narrow-minded’.[^8]  This complementarity of real and notional apprehension is an essential prerequisite for assent. Thus, the more clear and distinct the apprehension (to borrow Descartes’ phrase), the more cause we have for assent, and the more like a real apprehension one has, the more clear and distinct that apprehension. As Newman puts it (in very Humean terms), ‘what is concrete exerts a force and makes an impression on the mind which nothing can rival… the mind is ever stimulated in proportion to the cause stimulating it’,[^9]  and nothing stimulates the mind more, than direct experience. He concludes:

> As notions come of abstractions, so images come of experiences; the more fully the mind is occupied by an experience, the keener will be its assent, and on the other hand, the duller will be its assent and the less operative, the more it is engaged with an abstraction…[^10] 

**II. Belief Understood as Assent**

While it is true that apprehension attenuates with the category of object upon which the mind is fixed (being either real or notional), it is not the case that assent is tethered to apprehension in the same variable way. Newman puts it this way:

I observe that it is this variation in the mind’s apprehension of an object to which it assents, and not any incompleteness in assent itself, that leads us to speak of strong and weak assents, as if assent itself admitted of degrees. In either mode of apprehension, be it real or notional, the assent preserves its essential characteristic of being unconditional.[^11] 

The object of an assent is the truth of a given proposition. You either believe a proposition to be true, or you do not. There is no sliding scale of intellectual commitment. Newman offers a clarifying distinction by way of example: ‘… to infer, is to hold on sufficient grounds that free-trade may, must, or should be a benefit; to assent to the proposition, is to hold that free-trade is a benefit.’[^12] 

Thus, the man who infers is not necessarily assenting, and the man who assents is not necessarily assenting to a proposition that has been inferred as the conclusion of an inference. However, Newman says, ‘we can at once infer and assent… Indeed, in a multitude of cases we infer truths, or apparent truths, before, while, and after we assent to them’.[^13]  This means that we often assent to truths before we have the logic to justify them to ourselves by inference alone. In other words, intelligent assent is not *necessarily* dependent upon an inference from sound logical reasoning, even if the assent is about a notional apprehension (aka an abstraction). Newman uses ‘sufficient grounds’ in the quote above, to signal the requirements of traditional logic: propositions exhibiting transitivity, and conclusions that follow necessarily. A sound argument is sufficient ground for an inference. But assent requires no such ground. An inference may contribute to assent, but it is not necessary.

The importance of this distinction can be seen by example. ‘I hate you’, is just as eligible for assent as, ‘the sun is shining’. Or, to borrow Newman’s example, ‘there is revealed religion’, and ‘there is no revealed religion’ are both propositions that are eligible for assent, which is to say, are intelligible propositions that one can hold as a belief. In Newman’s example, it might be argued that reasons are needed to judge the belief *rational*, and that rationality is necessary as a justification for a belief, and that only justified beliefs are worthy of respect. So, whether or not revealed religion is real, requires some rationale. But it would make no sense to make the same complaint of propositions like, ‘the sun is shining’, or ‘I hate you’. On Newman’s interpretation, both of these propositions would constitute expressions of real assent. And, as was shown, no inference can be offered for real assent. It is the result of a direct impression on the mind, as a result of sense experience or internal feeling. What’s more, the more compelling the experience, the more compelled the assent. So, for example, ‘I am drowning’ would be a proposition immediately assented to, in a situation in which I was being dragged under the surf by a heavy weight wrapped around my ankle. But assent to that proposition is no more or less proportioned than assenting to, say, ‘Jesus died on the cross’.

The first proposition of the original argument under scrutiny was that a rational belief is one that is proportioned to the evidence. If the argument of this section is correct, then we are warranted in rejecting the first premise of the original argument. What has been shown so far, is that belief is one of two kinds of assent (real and notional) and that assent is not proportioned, but is rather immediate and total, even in situations where inference is involved. Furthermore, we have seen that the lack of inferential support does not necessarily imply that a belief is false. In the worst-case scenario where direct experience and inferential support are both lacking, what could be said is that the status of the belief was undetermined. But as we have seen, either some direct experience (whether as sensory witness, or as consumer of information), or inference, or testimony or revelation lies behind all assent, because all assents are the recognition of the truth of a proposition.[^14] 

But what of these various means of forming propositions? What are they and how should we regard them? The next section will address questions of standards of rationality and the role of evidence in justifying beliefs, in an attempt to answer these questions, and to give grounds for rejecting premise two of the scrutinized argument.

**III. What Makes a Belief Rational?**

Having put the question of belief and proportionality to bed in the last section, it is necessary to foreclose on the notion of rationality, which was left behind by the last section, before fully addressing the question of evidence.

Alvin Plantinga offers five plausible definitions for rationality in his book Warranted Christian Belief. He lists them as (a) Aristotelian human nature, (b) proper mental function, (c) within or conforming to the deliverances of reason, (d) utilitarian (‘means-ends’) cunning, and (e) deontological rationality.[^15]  There are two definitions from this list that concern this essay. First, is proper mental function, and the second is the idea of rationality as that which is within or conforming to the ‘deliverances of reason’. If it can be shown that certain religious beliefs are held (propositions are assented to) due to some malfunction in the rational faculty, or that the beliefs held are not in conformity with the deliverances of reason, then it could be said that those beliefs are irrational. While this would not fully support the conclusion of the argument under scrutiny, it would at least open the door to its possibility.

The rationality of proper mental function is essentially asking whether religious belief is the product of dysfunction of the rational faculty. It is to interpret the idea of the rational as the ‘sane’. Plantinga makes a distinction here between ‘internal rationality’, which he describes as ‘proper function of all belief-producing processes downstream from experience’, and the ‘upstream’ experiences, which he divides into two types: phenomenal (sensuous) imagery, and doxastic experience.[^16]  Beliefs formed as a result of phenomenal imagery are formed ‘in response to sensuous imagery and on the basis of such imagery’. They are beliefs of the kind expressed by Newman as ‘the sun is shining’, or ‘I see an elephant, and not a pink flamingo’. Proper functioning, here, would be to hold the belief that the sun is shining or that there is a pink flamingo before you, when you are in fact presented with the sense experience of sunshine or pink flamingos. Internal rationality, on Plantinga’s view, would prevent the perceptions from being understood as anything other than what they actually are. If there were an incongruity, it would have to be as a result of a malfunction in the senses, not the ‘belief-producing processes’.

Beliefs formed by way of doxastic experience, on the other hand, are beliefs grounded in phenomenal experiences unaccompanied by sense evidence. Such things as memories, the feeling of certainty itself, a priori understanding, and the awareness of the self, are all instances of doxastic experience, according to Plantinga, because they accompany belief formation but are unaccompanied by sense experience. So, for example, the memory of a party you attended in Cleveland, the feeling of certainty that it was *Cleveland* and not *New York*, the a priori understanding that a city is not a set, and the awareness that it is *you* who is recalling the memory of the party, and not your brother Tom in Toledo, would all be examples of doxastic experiences leading to specific beliefs. Here, it is is possible to exhibit ‘external’ irrationality, while still exhibiting internal rationality. Plantinga borrows Descartes’ famous example of the madmen who believe their heads are made of pottery. If the mind is ‘so troubled and clouded by the violent vapours of black bile that they… imagine that they have an earthenware head'[^17]  then it would be internally rational to believe so, and it would be pragmatically rational to, say, always wear a helmet, or to wash one’s head with dish soap or glass cleaner.

Here, one might think it easy to identify signs of external irrationality in religious beliefs. But this would be to assume the conclusion being sought. Plantinga defines external rationality as, ‘proper function with respect to the formation of the sensuous experience on which perceptual belief is based, and… in the formation of the right kind of doxastic experience — that is, the sort of doxastic experience required by proper function.'[^18]  So, to show that the beliefs of, say, a Christian, are irrational, one would have to show that both his perceptual and doxastic beliefs are the product of a perceptual or cognitive malfunction. But, everyday experience shows that this is not the case, at least cognitively. Most Christians are functional enough to raise families and hold steady jobs (some, even as academics, as Plantinga points out). So, a demonstration of irrationality on these grounds would require an appeal to evidence, and something Plantinga calls ‘warrant’ will address that move. This point will be concluded in the section on evidence.

The second kind of rationality is essentially Cartesian certainty. As Plantinga puts it, rationality ‘is the faculty or power whereby we see the truth of self-evident propositions… together with propositions that are self-evident consequences of [self-evident propositions]’.[^19]  So, a proposition ‘is rational if [it’s affirmation] is among the deliverances of reason, and irrational if its denial is among the deliverances of reason’. Plantinga asks and answers the question central to this essay, quite frankly: ‘Is Christian belief rational in this sense? No; the central truths of Christianity are certainly not self-evident, nor so far as anyone can see, are they such that they can be deduced from what is self-evident.'[^20]  Plantinga rightly points out, however, that this is not sufficient for condemning Christian belief as such. If it did mean that, then the same would hold for what is taught in courses on history, physics, and biology, because none of the central truths of those fields of study are self-evident.

But, is it possible that Christian belief is *irrational* on this account? In other words, are there propositions whose denial are among the deliverances of reason (either self-evident, or the self-evident consequences of deductions)? Plantinga does not think so. Even in the case of horny questions like the trinity and the incarnation, Plantinga argues that there are interpretational difficulties with the claim that these beliefs are internally contradictory or inconsistent.[^21]  So, even where a Christian may mistakenly hold one of these inconsistent formulations, he could still change his mind when presented with a consistent version. Thus, on this account of rationality, the believer is not necessarily irrational. What’s more, given that at least some Christian beliefs can be shown to be rational on this view, the conclusion of the argument under scrutiny could not possibly be true. It is not the case that religious faith is *never* rational.

**IV. What Is the Evidence?**

However, the charge levied against religious belief in the syllogism under scrutiny in this essay, was not that it was internally inconsistent, or logically fallacious, but that it was not ‘evidence proportional’ (as David Hume might have put it). A common criticism of the empiricist argument, from which evidentialism is derived, is that its own premises fail the test of empiricism. If nothing can be reasonably assented to that has not been received through sense experience, then why should we assent to the proposition that rational beliefs are proportioned to the evidence? It seems there is nothing compelling the assent.

But, what about *apprehension of a proposition itself*? Newman would have considered propositions, when expressed sincerely, to be evidence of certain kinds of beliefs. However, he would have balked at urging assent in the case of Hume’s famous proposition that ‘the wise man proportions his belief to the evidence’.[^22]  As has been shown already, belief is itself not a proportional matter. But, more to the point here, it’s also because what matters with regard to evidence, is not quantity, but quality. To put the point slightly differently, what sort of evidence is *appropriate* to religious belief? What counts as evidence? What makes one item relevant, and another not? This has been as much of a vexxing question in the philosophy of science, as it has for religion. As Peter-Godfrey Smith states, ‘What connection between an observation and a theory makes that observation evidence for the theory? In some ways, this has been the fundamental damental problem in the last hundred years of philosophy of science.'[^23] 

When asking questions that have things in the material world as their object, empiricism — the view that ‘the only source of real knowledge about the world is experience'[^24]  — is a good common sense starting point. This is (at least indirectly) what Hume had in mind, when he wrote his famous maxim about wise men in On Miracles.[^25]  How hot must water be, to boil? How tall is the Eiffel Tower? What is the average air speed velocity of an unladen swallow? We could, with a bit of effort, devise ways of discovering the answers to these questions on our own. Putting a thermometer into the kettle and waiting until the bubbles show up; going to Paris and using a few tricks of ancient Greek geometry and mathematics to ‘eyeball’ the size of the structure relative to the surrounding buildings; or, say, using a radar gun to measure the air speed velocity of an unladen swallow.[^26] 

Is this the kind of evidence that could be used to provide support for religious beliefs? Perhaps some beliefs would be amenable to physical evidence. For example, take belief in the phenomena of stigmata. We might be able to collect blood or skin tissue samples during the time someone is having an episode, or record certain physical conditions present at the moment of eruption of the phenomenon, or even take testimony from eye witnesses. But what does this information have to offer us? In the case of the Eiffel Tower, the information we collect seems directly connected to the question we are asking: namely, how tall is the structure? Linear measurements of the shadow, combined with calculations using distance to the structure and angle to its peak, will in fact give us (roughly speaking) the height at the peak. But what is the question we are asking about the person experiencing an episode of stigmata (or reporting that he had witnessed one)? The naive question is to ask whether or not its real, but what do we mean by ‘real’? Hume asked a slightly more sophisticated version: is it reasonable to believe that this person experienced a miracle? But this is in effect, the same question. Are miracles ‘real’?

Setting aside the adjudication of Hume’s case against them, the point here is to consider what evidence, understood as information collected from experience (understood as the systematic collection of material evidence), would help us answer that question? The Roman Catholic church adheres to a list of twelve criteria[^27]  — all of them forms of material evidence — that must be satisfied, before they will accept the phenomenon as a miracle. But the list has two interesting peculiarities. First, one of its primary purposes is to rule out imitators. For example, criteria 11 is ‘the wounds do not close perfectly and instantaneously’. This criteria exists because many have attempted to emulate stigmata by surreptitiously dabbing blood in their palms and ankles, to emulate the ‘real’ effect of stigmata. Second, it presupposes the reality of the incarnation. Critiera 1 says that the stigmata must be present on the body in all five places where Christ was wounded, and Criteria 12, says that the person experiencing the stigmata must be undergoing intense physical and moral suffering when the phenomenon ocurrs (congruent with the intense physical and moral suffering Christ underwent on the cross). To put it in the form of a modus pones: ‘if the incarnation is true, then then for a stigmata to be authentic it must exhibit the full effects of the crucifixion. The incarnation is true, and this particular stigmata does exhibit the effects of the crucifixion. Therefore this particular stigmata is authentic’.

The second point is the important one, here. If we accept just for the moment, that stigmata are instances of supernatural phenomena, it would not immediately follow that the phenomena were demonstrations of the truth of Christianity. Indeed, the church itself admits that the phenomenon can be classified into four different categories: (a) divine origin, (b) diabolical origin, (c) unknown origin, (d) psychological origin. By ‘divine origin’, the church just assumes Christian conception of God (which includes Christ as part of the Trinity), and everything else less than divine by degrees, concluding finally with a natural origin. But, setting aside the question of the assumed Christian theodicy, we can still ask if the presence of the background assumption of supernaturalism in general is reasonable, and whether physical evidence is indeed at least indicitive of that super nature. The case of stigmata does suggest that there is indeed a discernable difference between a hoaxer, a psychologically troubled person, and a genuine miracle, and (if the Catholic criteria is to be taken seriously) that physical evidence can provide support for assent in particular cases.

But suppose someone were to insist that the background assumption is enough to discredit this belief (recall, tha this is the charge of the original syllogism – that religious beliefs are unsupported). In that case, they would be condemning empiricism (and indeed all scientific beliefs) along with the religious beliefs. To show this in sharp relief, let’s zoom out a bit and consider the question of why it is that evidence is a support for any belief at all. Whether we take a confirmationist or a falsificationist view (or some combination of the two) of the role of evidence in a rational belief, we need to first ask ourselves what reason we have for ‘expecting patterns observed in our past experience to hold also in the future’.[^28]  This is the problem of induction, of course, and inductive skeptics might complain that we are just as foolish to expect tomorrow’s sunrise, as the Christian is to expect Christ’s return, because the physical evidence does not support the belief.

The inductive skeptic is correct to identify the position that the empiricist is in (though he may be overstating his case a bit), but what is key here, is what the condemnation implies. The empiricist is relying on an undefended background assumption. That background assumption is the belief that the universe is orderly and predictable, and that it always will be so. In more theological terms, the empiricist implictly assents to the proposition that the universe exhibits a self-evident design. If we take that presupposition as the major premise in a deductive syllogism, suddenly, the problem of induction in science doesn’t look like much of a problem anymore, because all reasoning ultimately resolves to a deduction beginning with the order of the universe. But what gives us sufficient reason to take this first premise as read? What evidence sustains the expectation? Ultimately, again, we are stuck with Hume’s ten thousand sunrises, and not much else.[^29] 

The point here, is not necessarily to prove the existence of God or even the existence of an overarching supernature. Rather, it is to highlight the need for something else besides mere evidence (even as it is rigorously conceived of in the scientific disciplines) in order to make a rational case. To say that the order of the universe is just a ‘brute fact’ or an axiom of which no question can be asked coherently, is to say that the universe itself is fundamentally irrational, despite all the order apparent to our sense experience, because there can be no explanation for it.[^30]  But if we are to remain committed to the implicit standard of the original syllogism (that beliefs must be rational to be respectable, and evidence-sensitive to be rational), then there are certain questions that cannot be answered rationally even if we take evidence into account, without also allowing for the possibility of explanations that extend beyond matter in motion. Thus, it might even be said that religious belief is not only supported by the evidence, but also it would be irrational to reject certain religious beliefs that are strongly suggested by the the very idea of evidence itself. For example, a belief in the existence of God.

**V.** **Faith As Co-Estensive With Rationality**

> ‘By means of what is material and temporary, we may lay hold upon that which is spiritual and eternal.’ ~ Augustine, De doctrina christiana[^31] 

The argument under scrutiny clearly defines faith as a religious belief, and simply asserts that a belief held on religious grounds is just what it means to be a belief held without evidence. This definition has been shown to be erroneous on several counts. But this still leaves us without a clear understanding of what faith is. The goal of this section, then, will be to outline a concept of faith that is in concord with the deliverances of reason (as Plantinga might put it), and incorporates evidence that is appropriate to the religious belief being considered, yet clearly distinguishes it from belief derived solely from inferences (whether evidence-sensitive or not).

According to John Bishop[^32] , conceptions of faith can be roughly divided into various different categories, some of which overlap. In the most broad sense, he distinguishes between faith understood as an individual ‘act’, and faith understood as the ‘state’ an individual is in. Taking the notion of faith as a state, understandings of faith can then further be divided into two groups of either cognitive or non-cognitive ‘models’. Under the cognitive head, he includes ‘special knowledge’, the ‘belief’, and the ‘doxastic venture’.

The ‘belief model’ of faith can be summarized as belief that propositions with theological content are true. This model of faith is one tightly coupled to reason, as its justifying method. Rational beliefs are obviously, then, beliefs that are justified to the degree that their arguments are rational, and supported by evidence. Swinburn (via Bishop) seems to think this could enable some religious beliefs to qualify as knowledge on the Justified True Belief theory of epistemology. For certain religious beliefs, this seems possible. For example, there are dozens of good arguments that purport to demonstrate the existence of God. Some begin with the assumption of God’s existence (similar to the case of stigmata above), and argue in modus ponens fashion to a state of affairs in the world. Others begin with an observation of a state of affairs in the world, and reason to God from it. Several of of the latter are highly convincing, as well as evidence-sensitive.[^33]  This is the kind of faith that Thomas Aquinas had in mind, and what is commonly refered to, today, as ‘natural theology’. It is the reasoned belief that existence includes the supernatural, and that the supernatural is where God can be found. This is, more or less, the implicit conception of faith this paper has been relying upon.

But this cannot be enough. If we can rest our belief in the existence of God on rationally inferred conclusions to arguments that drawn in particular from direct experience of things like change and order, why can we not simply call this a rational belief? What does the idea of faith add to our understanding of faith? If one can reason one’s way to the bare fact of the existence of God, then perhaps faith is not operative in that belief. How would we know the difference? According to Bishop, what distinguishes mere rational inferences from faith beliefs, is the content of the belief. So, for example, an argument for the existence of quarks or dark matter that resulted in firmly held beliefs that quarks and dark matter existed, would constitute natural beliefs. But arguments for the existence of God or sin or angels that led to beliefs that these things existed, would constitute faith beliefs. This raises all sorts of questions, of which there is unfortunately, no space left to address.

In any case, there seems to be a more significant problem with this conception of faith. Inferences of the kind that have been hinted at here (involving inductions from evidence) are not the kind that could result in the kind of certitude that, for example, Aquinas had in mind (Newman agrees on this point, as we saw at the beginning). ‘Full and direct comprehension'[^34] of God is only achievable by a gift of Grace, according to Aquinas. What’s more, as he says at the end of Question 2a2 of the Summa Theologiae, ‘the truths about God that St. Paul says we can know by our natural powers of reasoning… are not articles of faith. They are *presupposed* by them. For faith presupposes natural knowledge, just as grace does nature…’.[^35] 

It might appear that what is being suggested here, is that faith is simply a mechanism for supplying a degree of psychological confidence that inferred conclusions cannot, but this is not quite right. Rather, as was hinted at in the section on Newman, faith is something that stands alongside reason, so to speak. Assent is something that is granted, whether or not an inference accompanies it. Granting is an act, not a state.

Belief derived from inference, is a state that one arrives at that is not volitional. Assent, on the other hand, while something that must be induced, is nonetheless subject to the will. But what would induce a moment of choice like this? According to Aquinas, it is when God reveals the truth of articles of faith to us. Faith is the act of assenting to that revelation. On the belief model of faith, this is limited to propositional truths, but revelation is not limited to that. Mystical experiences of the kind that Paul had on the road to Damascus would also count. As well as everything in between. Paul did not have to believe that what happened to him was a visitation from Christ. Indeed, the ambiguity of the evidence in such a situation would enough to give anyone pause. But he chose to accept the supernatural explanation. Paul was a well educated man who was well versed both in Jewish and Christian scriptures, according to reports. So, it seems arbitrary to expect that he choose the purely natural explanation, when everything he’d learned up to that point suggested the reality of Christ instead.

So, the best conception of faith seems to be a version of Bishop’s belief model coupled with the special knowledge model. Reason gives us knowledge of the natural and provides us with clues to what must lie beyond. Faith gives us the capacity to know the God that reason tells us must be there somewhere, just beyond the senses.

**Conclusion**

This paper has shown that the first premise of the argument under scrutiny is false, because belief is not a proportional state, but a binary one. It has shown that the second premise is false, because religious beliefs are in fact evidence-sensitive, in spite of not being proportioned, and it has shown the conclusion to be erroneous because religious beliefs are at least sometimes rational as well as being evidence-sensitive.

Had the argument concluded with something a bit less ambitious than ‘never rational’, it may have had a point. Surely, there must be some specific beliefs we could identify as irrational. There are very definitely some beliefs within the Christian religion that are monstrously difficult to justify (as hinted at by Plantinga, for example, in the section on rationality). Another approach might have been to make a distinction as to what kinds of evidence were appropriate to certain beliefs (as argued in the section on evidence).

Yet, for all of its misguided oversimplification, the syllogism opening this paper rightly implies the difficulty a philosopher is faced with when considering the question of faith. This paper has been teetering on the very edge of what is not only reasonable to believe, but what it is even possible to believe, and at times it is difficult not to sound like a theologian. Metaphorically speaking, at the furthest edge of science, lies metaphysics; and, at the furthest edge of metaphysics, lies theology. As Aristotle puts it:

> …who can doubt that, if there is Divinity anywhere in the universe, then it is in the nature studied by First Science [theology] that It is to be found. And it is also for the Supreme Science to study the Supreme Genus [being itself]. And contemplative study is to be chosen above all other sciences, but it is this First Science of Theology that we must prefer to all other kinds of contemplation.[^36] 

We could take this as a warning, or as an invitation. As a warning, we are seeing Aristotle through the eyes of a modern: someone trained in the habit of naturalism; suspicious of speculations of the immaterial and the infinite. But as an invitation, we are seeing Aristotle through the eyes of virtually every philosopher from Boethius to Spinoza: as a mind open to evidence of a kind not available to the naturalist (like fishermen who deny the reality of cows, because their nets only ever haul in fish). If the co-founder of all western philosophy is willing to take that invitation seriously, then perhaps we should, too. Like the seeker in Flammarion’s famous engraving, then, let us peel back the veil and peer into the infinite.

---

**Bibliography**

Alston, W. 1991: Perceiving God. Ithaca: Cornell University Press (Kindle Edition)

Aristotle, 2016: Metaphysics. Online: The Big Nest (thebignest.co.uk) (Kindle Edition)

Bishop, J. 2016: Faith (Stanford Encyclopedia of Philosophy). [online] Plato.stanford.edu Available at: https://plato.stanford.edu/entries/faith/

Davies, B. and Leftow, B. (eds) 2006: Aquinas: Summa Theologiae, Questions on God. New York: Cambridge University Press

Feser, E. 2017: Five Proofs of the Existence of God. San Francisco: Ignatius Press

Forrest, P., 2017: The Epistemology of Religion (Stanford Encyclopedia of Philosophy). [online] Plato.stanford.edu. Available at: https://plato.stanford.edu/entries/religion-epistemology

Godfrey-Smith, Peter 2003: Theory and Reality – An Introduction to the Philosophy of Science. London: The University of Chicago Press (Kindle Edition)

Harrison, P. 2015: The Territories of Science and Religion. Chicago: University of Chicago Press

Helm, P. (ed) 1999: Faith and Reason. Oxford: Oxford University Press

Hume, D. and Millican, P. (ed) 2007: An Enquiry Concerning Human Understanding. New York: Oxford University Press (Kindle Edition)

John Paul II, Pope. 1998: Encyclical Letter – Fides et Ratio. London: The Incorporated Catholic Truth Society

Kenny, A. 1979: The God of the Philosophers. Oxford: Clarendon Press

Mitchell, B. (ed) 1971: Philosophy of Religion (Oxford Readings in Philosophy). Oxford: Oxford University Press

Monti, D. (ed) 2005: The Works of St. Bonaventure Volume IX – Breviloquium. New York: The Franciscan Institute

Newman, J. H. 2013: An Essay in Aid of a Grammar of Assent. USA: Assumption Press

Penelhum, T. 1995: Reason and Religious Faith. Boulder: Westview Press

Plantinga, A. 2000: Warranted Christian Belief. New York: Oxford University Press (Kindle Edition)

Plantinga, A. 2011: Where the Conflict Really Lies: Science, Religion, and Naturalism. New York: Oxford University Press (Kindle Edition)

```[Imported from exitingthecave.com on 28 November 2021]```

[^1]: Newman, John Henry Cardinal, An Essay in Aid of A Grammar of Assent, University of Notre Dame Press. Kindle Edition, Pg. 8

[^2]: ibid, pg. 9

[^3]: ibid, pg. 22

[^4]: ibid, pg. 23

[^5]: ibid, pg. 31

[^6]: ibid, pg. 31

[^7]: ibid, pg. 32

[^8]: ibid, pg. 34

[^9]: ibid, pg. 36

[^10]: ibid, pg. 35

[^11]: ibid, pg. 37

[^12]: ibid, pg. 5

[^13]: ibid, pg. 6

[^14]: The most common alternative interpretation of Newman’s apprehension and assent is divergent from my own. It says that Newman held that numerous beliefs of high probability, when combined, somehow amount to ‘more than the sum of their parts’, so to speak. I reject this interpretation, in favor of the one outlined herein, mainly because it reads Beyesian probability theory backward into Newman. A more complete description of both interpretations can be found in the Stanford Encyclopedia of Philosophy under the head ‘The Epistemology of Religion’. https://plato.stanford.edu/entries/religion-epistemology/

[^15]: Plantinga, Alvin, Warranted Christian Belief, Oxford University Press, Kindle Edition, 2000, Pg. 109

[^16]: ibid, pg. 110

[^17]: Descartes, Meditation 1, by way of Plantinga, pg. 111

[^18]: Plantinga, Alvin, Warranted Christian Belief, Oxford University Press, Kindle Edition, 2000, pp. 112-113

[^19]: ibid, pg. 113

[^20]: ibid, pg. 114

[^21]: ibid, pg. 115

[^22]: Hume, David; Peter Millican. An Enquiry concerning Human Understanding, Oxford World’s Classics, OUP Oxford. Kindle Edition, pg. 80

[^23]: Godfrey-Smith, Peter, Theory and Reality: An Introduction to the Philosophy of Science, Kindle Edition, 2003, Kindle Location 619

[^24]: ibid, Kindle Locations 179-185.

[^25]: Hume actually seemed more interested in validating testimony by way of reputation in On Miracles. However, in other writings (particularly his Treatise on Human Nature) he was very much interested in understanding what physical evidence could and could not tell us about the world.

[^26]: I leave it to the reader to choose African or European

[^27]: [Fr. Henry Vargas Holguín](https://aleteia.org/author/fr-henry-vargas-holguin/), What are the Stigmata and How do We Know if They are Authentic?, Aleteia [website], 8 Jan 2015, https://aleteia.org/2015/01/08/what-are-the-stigmata-and-how-do-we-know-if-they-are-authentic/

[^28]: Godfrey-Smith, Peter, Theory and Reality: An Introduction to the Philosophy of Science, Kindle Edition, Locations 620-621.

[^29]: Descartes also outlined this problem well in his Meditations, from the perspective of rational skepticism. In summary: there is no satisfactory way to demonstrate the truth of this piece of wax in my hand, without an appeal to a divine source of reason for that truth.

[^30]: For a thorough treatment of this point, I highly recommend Edward Feser’s book, ‘Five Proofs of the Existence of God’, particularly the arguments from Aristotle and Leibniz.

[^31]: Harrison, Peter, The Territories of Science And Religion, University of Chicago Press, 2015, Pg. 55

[^32]: Bishop, J. (2016). Faith. Stanford Encyclopedia of Philosophy. Stanford, CA: Center for the Study of Language and Information.

[^33]: Aquinas’ Five Ways, or Ed Feser’s Five Arguments, for example. Or the case made by Plotinus, Bonaventure, and other neo-Platonists, if that is more to your taste. It is beyond the scope of this essay to evaluate particular arguments for the existence of God. But if at least one could be shown to be sound and convincing, the belief would be justified.

[^34]: Davies, B. & Leftow, B. (ed), Aquinas: Summa Theologiea, Questions On God, Cambridge University Press, 2006, Pg. 21

[^35]: ibid, Pg. 23

[^36]: Aristotle, Lawson-Tancred, Hugh (Ed), The Metaphysics Book 1, Penguin Books Ltd., 1998, Kindle Edition, Pg. 155
